@@ -1,4 +1,4 @@
-# Date::Parse $Id: //depot/TimeDate/lib/Date/Parse.pm#15 $
+# Date::Parse $Id: //depot/TimeDate/lib/Date/Parse.pm#21 $
 #
 # Copyright (c) 1995 Graham Barr. All rights reserved. This program is free
 # software; you can redistribute it and/or modify it under the same terms
@@ -17,7 +17,7 @@ use Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(&strtotime &str2time &strptime);
 
-$VERSION = "2.24";
+$VERSION = "2.26";
 
 my %month = (
 	january		=> 0,
@@ -75,7 +75,7 @@ sub {
   my $dtstr = lc shift;
   my $merid = 24;
 
-  my($year,$month,$day,$hh,$mm,$ss,$zone,$dst);
+  my($year,$month,$day,$hh,$mm,$ss,$zone,$dst,$frac);
 
   $zone = tz_offset(shift) if @_;
 
@@ -85,15 +85,17 @@ sub {
 
   # ignore day names
   $dtstr =~ s#([\d\w\s])[\.\,]\s#$1 #sog;
+  $dtstr =~ s/,/ /g;
   $dtstr =~ s#($daypat)\s*(den\s)?# #o;
   # Time: 12:00 or 12:00:00 with optional am/pm
+
+  return unless $dtstr =~ /\S/;
   
-  if ($dtstr =~ s/(?:^|\s)(\d{4})([-:]?)(\d\d?)\2(\d\d?)(?:[Tt ](\d\d?)(?:([-:]?)(\d\d?)(?:\6(\d\d?)(?:[.,]\d+)?)?)?)?\b/ /) {
-    ($year,$month,$day,$hh,$mm,$ss) = ($1,$3-1,$4,$5,$7,$8);
+  if ($dtstr =~ s/\s(\d{4})([-:]?)(\d\d?)\2(\d\d?)(?:[Tt ](\d\d?)(?:([-:]?)(\d\d?)(?:\6(\d\d?)(?:[.,](\d+))?)?)?)?(?=\D)/ /) {
+    ($year,$month,$day,$hh,$mm,$ss,$frac) = ($1,$3-1,$4,$5,$7,$8,$9);
   }
 
   unless (defined $hh) {
-
     if ($dtstr =~ s#[:\s](\d\d?):(\d\d?)(:(\d\d?)(?:\.\d+)?)?\s*(?:([ap])\.?m?\.?)?\s# #o) {
       ($hh,$mm,$ss) = ($1,$2,$4 || 0);
       $merid = $ampm{$5} if $5;
@@ -107,6 +109,11 @@ sub {
     }
   }
     
+  if (defined $hh and $hh <= 12 and $dtstr =~ s# ([ap])\.?m?\.?\s# #o) {
+    $merid = $ampm{$1};
+  }
+
+
   unless (defined $year) {
     # Date: 12-June-96 (using - . or /)
     
@@ -153,7 +160,7 @@ sub {
     $zone = tz_offset($1);
     return unless defined $zone;
   }
-  elsif ($dtstr =~ s#\s([a-z]{3,4})?([\-\+]?)-?(\d\d?)(\d\d)?(00)?\s# #o) {
+  elsif ($dtstr =~ s#\s([a-z]{3,4})?([\-\+]?)-?(\d\d?):?(\d\d)?(00)?\s# #o) {
     my $m = defined($4) ? "$2$4" : 0;
     my $h = "$2$3";
     $zone = defined($1) ? tz_offset($1) : 0;
@@ -189,6 +196,7 @@ sub {
   $year -= 1900 if defined $year && $year > 1900;
 
   $zone += 3600 if defined $zone && $dst;
+  $ss += "0.$frac" if $frac;
 
   return ($ss,$mm,$hh,$day,$month,$year,$zone);
 }
@@ -312,20 +320,11 @@ failure.
 =head1 MULTI-LANGUAGE SUPPORT
 
 Date::Parse is capable of parsing dates in several languages, these are
-English, French, German and Italian. Changing the language is done via
-a static method call, for example
-
-	Date::Parse->language('German');
-
-will cause Date::Parse to attempt to parse any subsequent dates in German.
-
-This is only a first pass, I am considering changing this to be
+English, French, German and Italian.
 
 	$lang = Date::Language->new('German');
 	$lang->str2time("25 Jun 1996 21:09:55 +0100");
 
-I am open to suggestions on this.
-
 =head1 EXAMPLE DATES
 
 Below is a sample list of dates that are known to be parsable with Date::Parse
@@ -342,6 +341,11 @@ Below is a sample list of dates that are known to be parsable with Date::Parse
  1999 10:02:18 "GMT"
  16 Nov 94 22:28:20 PST 
 
+=head1 LIMITATION
+
+Date::Parse uses Time::Local internally, so is limited to only parsing dates
+which result in valid values for Time::Local::timelocal
+
 =head1 BUGS
 
 When both the month and the date are specified in the date as numbers
@@ -368,5 +372,5 @@ as Perl itself.
 
 =cut
 
-# $Id: //depot/TimeDate/lib/Date/Parse.pm#15 $
+# $Id: //depot/TimeDate/lib/Date/Parse.pm#21 $
 
